Module options

Module options 

Structs

ByteCount
CallerOptions
Connect
DataRate
Encryption
KeyMaterialRefresh
ListenerOptions
PacketCount
PacketPeriod
PacketRate
PacketSize
Passphrase
Percent
Receiver
RendezvousOptions
Sender
Session
SocketAddress
SocketOptions
SrtVersion
Serialied, it looks like: major * 0x10000 + minor * 0x100 + patch
StreamId
A string that can be set on the socket prior to connecting. The listener side will be able to retrieve this stream ID from the socket that is returned from srt_accept (for a connected socket with that stream ID). This string can be used completely free-form. However, it’s highly recommended to follow the SRT Access Control (Stream ID) Guidlines.
Valid

Enums

BindOptions
KeySize
LiveBandwidthMode
https://datatracker.ietf.org/doc/html/draft-sharabayko-srt-00#section-5.1.1
OptionsError
SocketAddressParseError
SocketHost
StreamIdError

Traits

CompositeValidation
OptionsOf
Validation

Functions

url_parse