[−][src]Struct srt_protocol::protocol::connection::Connection
Handing connection timeout, etc The only events that this entity cares about is when packets are recevied from the remote, and when packets are sent from the remote
Implementations
impl Connection[src]
pub fn new(conn: ConnectionSettings) -> Self[src]
pub fn on_packet(&mut self, now: Instant)[src]
pub fn on_send(&mut self, now: Instant)[src]
pub fn next_action(&mut self, now: Instant) -> ConnectionAction[src]