KeyMaterialRefreshSettings

Struct KeyMaterialRefreshSettings 

pub struct KeyMaterialRefreshSettings { /* private fields */ }

Implementations

Source

impl KeyMaterialRefreshSettings

pub fn new( period: usize, pre_announcement_period: usize, ) -> Result<Self, KeyMaterialRefreshSettingsError>

pub fn period(&self) -> usize

pub fn pre_announcement_period(&self) -> usize

pub fn with_period( self, period: usize, ) -> Result<Self, KeyMaterialRefreshSettingsError>

KM Refresh Period specifies the number of packets to be sent before switching to the new SEK

The recommended KM Refresh Period is after 2^25 packets encrypted with the same SEK are sent.

pub fn with_pre_announcement_period( self, pre_announcement_period: usize, ) -> Result<Self, KeyMaterialRefreshSettingsError>

KM Pre-Announcement Period specifies when a new key is announced in a number of packets before key switchover. The same value is used to determine when to decommission the old key after switchover.

The recommended KM Pre-Announcement Period is 4000 packets (i.e. a new key is generated, wrapped, and sent at 2^25 minus 4000 packets; the old key is decommissioned at 2^25 plus 4000 packets).